# CodeMirror: Sass mode

// Variable Definitions $page-width: 800px $sidebar-width: 200px $primary-color: #eeeeee // Global Attributes body font: family: sans-serif size: 30em weight: bold // Scoped Styles #contents width: $page-width #sidebar float: right width: $sidebar-width #main width: $page-width - $sidebar-width background: $primary-color h2 color: blue #footer height: 200px

MIME types defined: `text/x-sass`.